@@ -7,7 +7,7 @@
 ** Comments: Support for dynamic port mapping.  This allows a protocol to
 ** to listened for on a non-standard port.
 **
-** $Id: dynports.c,v 1.2 2001/04/26 23:49:50 mborella Exp $
+** $Id: dynports.c,v 1.3 2001/10/07 19:17:40 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -116,6 +116,8 @@ void dynports_parse(char *s)
     f = dump_snmp;
   if (!strcmp(s, "slp"))
     f = dump_slp;
+  if (!strcmp(s, "ftpctrl"))
+    f = dump_ftpctrl;
   if (f==NULL)
     error_fatal("dynamic port assignment to unknown protocol %s", s);
 
