@@ -5,7 +5,7 @@
 **
 ** Comments: Functions to handle certain IP protocol numbers
 **
-** $Id: ip_services.c,v 1.8 2001/04/02 23:18:28 mborella Exp $
+** $Id: ip_services.c,v 1.9 2001/10/07 19:17:40 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -178,6 +178,10 @@ service_func_t port2func(u_int16_t port)
 	case PORT_PPTP:
 	  f = dump_pptp;
 	  break;
+
+	case PORT_FTPCTRL:
+	  f = dump_ftpctrl;
+	  break;
       
 	default:
 	  f = NULL;
