@@ -5,7 +5,7 @@
 **
 ** Comments: PPP module.
 **
-** $Id: ppp.c,v 1.9 2001/05/28 19:24:04 mborella Exp $
+** $Id: ppp.c,v 1.12 2001/10/02 22:28:33 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,13 +29,15 @@
  * PPP protocol types
  */
 
-#define PPP_PROTOCOL_IP      0x0021
-#define PPP_PROTOCOL_IPCP    0x8021
-#define PPP_PROTOCOL_IPXCP   0x802b
-#define PPP_PROTOCOL_LCP     0xc021
-#define PPP_PROTOCOL_PAP     0xc023
-#define PPP_PROTOCOL_CHAP    0xc223
-#define PPP_PROTOCOL_CCP     0x80fd
+#define PPP_PROTOCOL_IP               0x0021
+#define PPP_PROTOCOL_IPCP             0x8021
+#define PPP_PROTOCOL_IPXCP            0x802b
+#define PPP_PROTOCOL_LCP              0xc021
+#define PPP_PROTOCOL_PAP              0xc023
+#define PPP_PROTOCOL_CHAP             0xc223
+#define PPP_PROTOCOL_CCP              0x80fd
+#define PPP_PROTOCOL_COMPRESSED_FRAME 0x00fd
+#define PPP_PROTOCOL_CBCP             0xc029
 
 /*
  * PPP protocol map
@@ -43,13 +45,15 @@
 
 strmap_t ppp_protocol_map[] =
 {
-  { PPP_PROTOCOL_IP,      "IP" },
-  { PPP_PROTOCOL_IPCP,    "IPCP" },
-  { PPP_PROTOCOL_IPXCP,   "IPXCP" },
-  { PPP_PROTOCOL_LCP,     "LCP" },
-  { PPP_PROTOCOL_PAP,     "PAP" },
-  { PPP_PROTOCOL_CHAP,    "CHAP" },
-  { PPP_PROTOCOL_CCP,     "CCP" },
+  { PPP_PROTOCOL_IP,               "IP" },
+  { PPP_PROTOCOL_IPCP,             "IPCP" },
+  { PPP_PROTOCOL_IPXCP,            "IPXCP" },
+  { PPP_PROTOCOL_LCP,              "LCP" },
+  { PPP_PROTOCOL_PAP,              "PAP" },
+  { PPP_PROTOCOL_CHAP,             "CHAP" },
+  { PPP_PROTOCOL_CCP,              "CCP" },
+  { PPP_PROTOCOL_COMPRESSED_FRAME, "compressed frame" },
+  { PPP_PROTOCOL_CBCP,             "CBCP" },
   { 0, "" }
 };
 
@@ -136,9 +140,10 @@ void dump_ppp(packet_t *pkt)
       u_int8_t temp_protocol;
 
       /*
-       * Get the protocol.  The the protocol is "0x21" then it is only
+       * Get the protocol.  If the protocol is "0x21" then it is only
        * one byte and compression is suppressing the "0x00" - i.e., its a 
-       * damn IP packet.
+       * damn IP packet.  If is one byte and is "0xfd", its a compressed
+       * PPP frame and therefore we cannot decode it.
        *
        * This is a quick fix = it could be made more robust
        */
@@ -146,7 +151,8 @@ void dump_ppp(packet_t *pkt)
       if (look_packet_bytes((u_int8_t *) &temp_protocol, pkt, 1) == 0)
 	return;
 
-      if (temp_protocol == PPP_PROTOCOL_IP)
+      if (temp_protocol == PPP_PROTOCOL_IP || 
+	  temp_protocol == PPP_PROTOCOL_COMPRESSED_FRAME)
 	{
 	  if (get_packet_bytes((u_int8_t *) &temp_protocol, pkt, 1) == 0)
 	    return;
@@ -199,6 +205,20 @@ void dump_ppp(packet_t *pkt)
       dump_ipcp(pkt);
       break;
 
+    case PPP_PROTOCOL_CBCP:
+      dump_cbcp(pkt);
+      break;
+
+    case PPP_PROTOCOL_CCP:
+      dump_ccp(pkt);
+      break;
+
+    case PPP_PROTOCOL_COMPRESSED_FRAME:
+      /* If MPPC was given as the default CCP algorithm, dump it */
+      if (!strcmp(my_args->C, "mppc"))
+	dump_mppc(pkt);
+      break;
+
     default:
       /* dump data here! */
       break;
