@@ -5,7 +5,7 @@
 **
 ** Comments: PPP module definitions.
 **
-** $Id: ppp.h,v 1.4 2000/09/28 00:45:28 mborella Exp $
+** $Id: ppp.h,v 1.7 2001/10/07 19:17:40 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -33,6 +33,9 @@
 #include "lcp.h"
 #include "chap.h"
 #include "ipcp.h"
+#include "ccp.h"
+#include "cbcp.h"
+#include "mppc.h"
 
 void dump_ppp(packet_t *);
 
