@@ -5,7 +5,7 @@
 **
 ** Comments: Dump RIP header information. 
 **
-** $Id: rip.c,v 1.12 2001/03/27 20:45:36 mborella Exp $
+** $Id: rip.c,v 1.13 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -61,6 +61,8 @@ void dump_rip(packet_t *pkt)
   u_int16_t            address_family;
   int route_count;
 
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
 
   /* 
    * Look at the version to determine whether to use v1 or v2
